@@ -34,6 +34,8 @@
 
 #include "capplet-util.h"
 #include "gconf-property-editor.h"
+#include "activate-settings-daemon.h"
+#include <../accessibility/keyboard/accessibility-keyboard.h>
 
 enum
 {
@@ -52,7 +54,7 @@ create_dialog (void)
 }
 
 static GConfValue *
-rate_to_widget (GConfValue *value) 
+rate_to_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	GConfValue *new_value;
 	int rate;
@@ -74,7 +76,7 @@ rate_to_widget (GConfValue *value)
 }
 
 static GConfValue *
-rate_from_widget (GConfValue *value) 
+rate_from_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	static int rates[] = {
 		255, 192, 64, 1
@@ -89,7 +91,7 @@ rate_from_widget (GConfValue *value)
 }
 
 static GConfValue *
-delay_to_widget (GConfValue *value) 
+delay_to_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	GConfValue *new_value;
 	int delay;
@@ -111,7 +113,7 @@ delay_to_widget (GConfValue *value)
 }
 
 static GConfValue *
-delay_from_widget (GConfValue *value) 
+delay_from_widget (GConfPropertyEditor *peditor, GConfValue *value) 
 {
 	static int delays[] = {
 		1000, 700, 300, 0
@@ -125,13 +127,13 @@ delay_from_widget (GConfValue *value)
 }
 
 static GConfEnumStringPair bell_enums[] = {
-	{ 0, "custom" },
+	{ 0, "off" },
 	{ 1, "on" },
-	{ 2, "off" }
+	{ 2, "custom" }
 };
 
 static GConfValue *
-bell_from_widget (GConfValue *value) 
+bell_from_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	GConfValue *new_value;
 
@@ -143,15 +145,17 @@ bell_from_widget (GConfValue *value)
 }
 
 static GConfValue *
-bell_to_widget (GConfValue *value) 
+bell_to_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	GConfValue *new_value;
 	gint val = 2;
 
 	new_value = gconf_value_new (GCONF_VALUE_INT);
-	gconf_string_to_enum (bell_enums,
-			      gconf_value_get_string (value),
-			      &val);
+	if (value->type == GCONF_VALUE_STRING) {
+		gconf_string_to_enum (bell_enums,
+				      gconf_value_get_string (value),
+				      &val);
+	}
 	gconf_value_set_int (new_value, val);
 
 	return new_value;
@@ -159,7 +163,7 @@ bell_to_widget (GConfValue *value)
 
 
 static GConfValue *
-blink_from_widget (GConfValue *value) 
+blink_from_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	GConfValue *new_value;
 
@@ -170,7 +174,7 @@ blink_from_widget (GConfValue *value)
 }
 
 static GConfValue *
-blink_to_widget (GConfValue *value) 
+blink_to_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	GConfValue *new_value;
 	gint current_rate;
@@ -300,6 +304,14 @@ get_legacy_settings (void)
 	COPY_FROM_LEGACY (int,  "/gnome/desktop/peripherals/keyboard/bell_duration", "/Desktop/Bell/duration=100");
 }
 
+static void
+setup_accessibility (GladeXML *dialog, GConfChangeSet *changeset)
+{
+	GtkWidget *notebook = WID ("notebook1");
+	GtkWidget *label = gtk_label_new (_("Accessibility"));
+	GtkWidget *page = setup_accessX_dialog (changeset, FALSE);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
+}
 
 int
 main (int argc, char **argv) 
@@ -320,15 +332,17 @@ main (int argc, char **argv)
 		{ NULL, '\0', 0, NULL, 0, NULL, NULL }
 	};
 
-	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-	bind_textdomain_codeset (PACKAGE, "UTF-8");
-	textdomain (PACKAGE);
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
 
 	gnome_program_init (argv[0], VERSION, LIBGNOMEUI_MODULE, argc, argv,
 			    GNOME_PARAM_POPT_TABLE, cap_options,
 			    GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
 			    NULL);
 
+	activate_settings_daemon ();
+	
 	client = gconf_client_get_default ();
 	gconf_client_add_dir (client, "/desktop/gnome/peripherals/keyboard", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 	gconf_client_add_dir (client, "/desktop/gnome/interface", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
@@ -339,6 +353,7 @@ main (int argc, char **argv)
 		changeset = NULL;
 		dialog = create_dialog ();
 		setup_dialog (dialog, changeset);
+		setup_accessibility (dialog, changeset);
 
 		gtk_widget_show_all (WID ("keyboard_dialog"));
 		gtk_main ();
